@@ -1,4 +1,4 @@
-;# $Id: Storable.pm,v 1.0.1.6 2000/11/05 17:20:25 ram Exp $
+;# $Id: Storable.pm,v 1.0.1.9 2001/02/17 12:37:32 ram Exp $
 ;#
 ;#  Copyright (c) 1995-2000, Raphael Manfredi
 ;#  
@@ -6,6 +6,15 @@
 ;#  in the README file that comes with the distribution.
 ;#
 ;# $Log: Storable.pm,v $
+;# Revision 1.0.1.9  2001/02/17 12:37:32  ram
+;# patch10: forgot to increase version number at previous patch
+;#
+;# Revision 1.0.1.8  2001/02/17 12:24:37  ram
+;# patch8: fixed incorrect error message
+;#
+;# Revision 1.0.1.7  2001/01/03 09:39:02  ram
+;# patch7: added CAN_FLOCK to determine whether we can flock() or not
+;#
 ;# Revision 1.0.1.6  2000/11/05 17:20:25  ram
 ;# patch6: increased version number
 ;#
@@ -47,7 +56,7 @@ package Storable; @ISA = qw(Exporter DynaLoader);
 use AutoLoader;
 use vars qw($forgive_me $VERSION);
 
-$VERSION = '1.006';
+$VERSION = '1.010';
 *AUTOLOAD = \&AutoLoader::AUTOLOAD;		# Grrr...
 
 #
@@ -90,6 +99,21 @@ sub logcarp;
 
 sub retrieve_fd { &fd_retrieve }		# Backward compatibility
 
+#
+# Determine whether locking is possible, but only when needed.
+#
+
+my $CAN_FLOCK;
+
+sub CAN_FLOCK {
+	return $CAN_FLOCK if defined $CAN_FLOCK;
+	require Config; import Config;
+	return $CAN_FLOCK =
+		$Config{'d_flock'} ||
+		$Config{'d_fcntl_can_lock'} ||
+		$Config{'d_lockf'};
+}
+
 bootstrap Storable;
 1;
 __END__
@@ -139,12 +163,12 @@ sub _store {
 	my $self = shift;
 	my ($file, $use_locking) = @_;
 	logcroak "not a reference" unless ref($self);
-	logcroak "too many arguments" unless @_ == 2;	# No @foo in arglist
+	logcroak "wrong argument number" unless @_ == 2;	# No @foo in arglist
 	local *FILE;
 	open(FILE, ">$file") || logcroak "can't create $file: $!";
 	binmode FILE;				# Archaic systems...
 	if ($use_locking) {
-		if ($^O eq 'dos') {
+		unless (&CAN_FLOCK) {
 			logcarp "Storable::lock_store: fcntl/flock emulation broken on $^O";
 			return undef;
 		}
@@ -264,7 +288,7 @@ sub _retrieve {
 	my $self;
 	my $da = $@;							# Could be from exception handler
 	if ($use_locking) {
-		if ($^O eq 'dos') {
+		unless (&CAN_FLOCK) {
 			logcarp "Storable::lock_store: fcntl/flock emulation broken on $^O";
 			return undef;
 		}
